@@ -69,7 +69,8 @@ class BaseProcessor:
     int_to_datetime_fields: tuple = (
         "createTime",
         "created",
-        "createDate" "expiry",
+        "createDate",
+        "expiry",
         "expiryDate",
         "fundingTimestamp",
         "nextFundingTimestamp",
@@ -85,13 +86,19 @@ class BaseProcessor:
         "previousFundingDatetime",
     )
     numeric_fields: tuple = (
-        "availableBalance",
         "ask",
+        "askImpliedVolatility",
+        "askPrice",
+        "askSize",
         "askVolume",
+        "availableBalance",
         "average",
         "baseRate",
         "baseVolume",
         "bid",
+        "bidImpliedVolatility",
+        "bidPrice",
+        "bidSize",
         "bidVolume",
         "buySellRatio",
         "buyVol",
@@ -103,16 +110,19 @@ class BaseProcessor:
         "contracts",
         "crossUnPnl",
         "crossWalletBalance",
+        "delta",
         "entryPrice",
         "exercisePrice",
         "fee_cost",
         "fee_currency",
         "free",
         "freeze",
+        "gamma",
         "indexPrice",
         "initialMargin",
         "initialMarginPercentage",
         "last",
+        "lastPrice",
         "leverage",
         "liquidationPrice",
         "locked",
@@ -124,6 +134,7 @@ class BaseProcessor:
         "marginBalance",
         "marginLevel",
         "marginRatio",
+        "markImpliedVolatility",
         "markPrice",
         "maxNotional",
         "maxWithdrawAmount",
@@ -142,16 +153,20 @@ class BaseProcessor:
         "quoteRate",
         "quoteVolume",
         "realStrikePrice",
+        "rho",
         "sellVol",
         "shortAccount",
         "strike",
         "strikePrice",
+        "theta",
         "totalAssetOfBtc",
         "totalCollateralValueInUSDT",
         "totalLiabilityOfBtc",
         "totalNetAssetOfBtc",
+        "underlyingPrice",
         "unrealizedPnl",
         "unrealizedProfit",
+        "vega",
         "vwap",
         "walletBalance",
         "withdrawing",
